@@ -50,7 +50,7 @@
 			thisrow <- subset(colrow, colrow[,2] == rows[i])
 			colrow[colrow[,2]==rows[i], 3] <- v[thisrow[,1]]
 		}	
-	} else {
+	} else if (nc$var[[zvar]]$ndims == 3) {
 		count = c(x@ncols, 1, 1)
 		for (i in 1:length(rows)) {
 			start = c(1, readrows[i], time)
@@ -58,6 +58,24 @@
 			thisrow <- subset(colrow, colrow[,2] == rows[i])
 			colrow[colrow[,2]==rows[i], 3] <- v[thisrow[,1]]
 		}	
+	} else {
+		if (x@data@dim3 == 4) {
+			count = c(x@ncols, 1, x@data@level, 1)
+			for (i in 1:length(rows)) {
+				start = c(1, readrows[i], x@data@level, time)
+				v <- as.vector(get.var.ncdf(nc, varid=zvar, start=start, count=count))
+				thisrow <- subset(colrow, colrow[,2] == rows[i])
+				colrow[colrow[,2]==rows[i], 3] <- v[thisrow[,1]]
+			}
+		} else {
+			count = c(x@ncols, 1, 1, x@data@level)
+			for (i in 1:length(rows)) {
+				start = c(1, readrows[i], time, x@data@level)
+				v <- as.vector(get.var.ncdf(nc, varid=zvar, start=start, count=count))
+				thisrow <- subset(colrow, colrow[,2] == rows[i])
+				colrow[colrow[,2]==rows[i], 3] <- v[thisrow[,1]]
+			}
+		}
 	}
 	
 	colrow <- colrow[,3]
@@ -85,7 +103,8 @@
 
 	
 # read cell by cell
-	zvar = x@data@zvar
+	zvar <- x@data@zvar
+	dim3 <- x@data@dim3
 	cols <- colFromCell(x, cells)
 	rows <- rowFromCell(x, cells)
 	if ( x@file@toptobottom ) { rows <- x@nrows - rows + 1 }
@@ -101,13 +120,29 @@
 			start = c(cols[i], rows[i])
 			res[i] <- get.var.ncdf(nc, varid=zvar, start=start, count=count)
 		}	
-	} else {
+	} else if (nc$var[[zvar]]$ndims == 3) {
 		count = c(1, 1, nl)
-		res <- matrix(nrow=length(cells), ncol=nlayers)
+		res <- matrix(nrow=length(cells), ncol=nl)
 		for (i in 1:length(cells)) {
 			start = c(cols[i], rows[i], layer)
 			res[i,] <- get.var.ncdf(nc, varid=zvar, start=start, count=count)
 		}	
+	} else {
+		if (x@data@dim3 == 4) {
+			count = c(1, 1, x@data@level, nl)
+			res <- matrix(nrow=length(cells), ncol=nl)
+			for (i in 1:length(cells)) {
+				start = c(cols[i], rows[i], x@data@level, layer)
+				res[i,] <- get.var.ncdf(nc, varid=zvar, start=start, count=count)
+			}	
+		} else {
+			count = c(1, 1, nl, x@data@level)
+			res <- matrix(nrow=length(cells), ncol=nl)
+			for (i in 1:length(cells)) {
+				start = c(cols[i], rows[i], layer, x@data@level)
+				res[i,] <- get.var.ncdf(nc, varid=zvar, start=start, count=count)
+			}	
+		}
 	}
 
 	#if (!is.na(x@file@nodatavalue)) { res[res==x@file@nodatavalue] <- NA	}
