@@ -17,10 +17,11 @@ function(x, r=1, g=2, b=3, scale, maxpixels=500000, extent=NULL, interpolate=FAL
 	if (!axes) par(plt=c(0,1,0,1))
 
 	if (missing(scale)) {
-		if ( x@data@haveminmax ) {
-			scale <- max(max(x@data@max), 255)
-		} else {
-			scale <- 255
+		scale <- 255
+		if (! inherits(x, 'RasterStack')) {
+			if ( x@data@haveminmax ) {
+				scale <- max(max(x@data@max), 255)
+			}
 		}
 	}
 	
